@@ -1,4 +1,5 @@
-
+#' @keywords internal
+"_PACKAGE"
 
 #' BeastJar
 #'
@@ -6,7 +7,6 @@
 #' to facilitate Markov chain Monte Carlo sampling techniques including Hamiltonian Monte Carlo,
 #' bouncy particle sampling and zig-zag sampling.
 #'
-#' @docType package
 #' @name BeastJar
 #' @import rJava
 #' @examples
@@ -38,7 +38,7 @@
 #'   joint$add(rJava::.jcast(model, "dr.inference.model.Likelihood"))
 #'   joint$add(rJava::.jcast(dummy, "dr.inference.model.Likelihood"))
 #'
-#'   joint <- rJava::new(rJava::J("dr.inference.model.CompoundLikelihood"), joint)
+#'   joint <- rJava::new(rJava::J("dr.inference.model.CompoundLikelihood"), 1L, joint)
 #'
 #'   # Specify auto-adapting random-walk Metropolis-Hastings transition kernel
 #'   operator <- rJava::.jnew("dr.inference.operators.RandomWalkOperator",
